# Generated by Django 3.2.18 on 2023-03-07 09:47

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_peeringdb", "0025_campus"),
    ]

    operations = [
        migrations.AddField(
            model_name="facility",
            name="social_media",
            field=models.JSONField(
                blank=True, default=dict, verbose_name="Social Media"
            ),
        ),
        migrations.AddField(
            model_name="campus",
            name="social_media",
            field=models.JSONField(
                blank=True, default=dict, verbose_name="Social Media"
            ),
        ),
        migrations.AddField(
            model_name="carrier",
            name="social_media",
            field=models.JSONField(
                blank=True, default=dict, verbose_name="Social Media"
            ),
        ),
        migrations.AddField(
            model_name="internetexchange",
            name="social_media",
            field=models.JSONField(
                blank=True, default=dict, verbose_name="Social Media"
            ),
        ),
        migrations.AddField(
            model_name="network",
            name="social_media",
            field=models.JSONField(
                blank=True, default=dict, verbose_name="Social Media"
            ),
        ),
        migrations.AddField(
            model_name="organization",
            name="social_media",
            field=models.JSONField(
                blank=True, default=dict, verbose_name="Social Media"
            ),
        ),
    ]
